@@ -53,7 +53,7 @@ def create_app(config_override: Dict[str, Any] = None, environment: str = None)
     logger.setup_logging(app)
 
     if app.config['USE_PROXYFIX']:
-        app.wsgi_app = ProxyFix(app.wsgi_app)
+        app.wsgi_app = ProxyFix(app.wsgi_app)  # type: ignore
 
     hooks.init_app(app)
     audit.init_app(app)
